# UI/UX Feedback

**ID:** Feedback-20260219-162148
**URL:** http://127.0.0.1:5858/
**Date:** 2026-02-19 16:22:11

## Selected Elements

- `{'selector': 'div.workflow-modal', 'parents': ['div.workflow-modal-overlay']}`

## Feedback

when we composing idea, still old modal window

## Screenshot

![Screenshot](./page-screenshot.png)
